@@ -20,7 +20,7 @@ from codemeta.common import getstream, init_graph, AttribDict, SDO, RDF, CODEMET
 from codemeta.parsers.jsonld import parse_jsonld
 import argparse
 
-VERSION = "0.3.0" #also adapt in setup.py
+VERSION = "0.3.1" #also adapt in setup.py and codemeta.json
 
 STATIC_DIR = os.path.join(CODEMETAPATH[0], "resources")
 
@@ -30,11 +30,18 @@ PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
 PREFIX schema: <http://schema.org/>
 PREFIX codemeta: <https://codemeta.github.io/terms/>
 PREFIX stype: <https://w3id.org/software-types#>
+PREFIX iodata: <https://w3id.org/software-iodata#>
 PREFIX repostatus: <https://www.repostatus.org/#>
+PREFIX trl: <https://w3id.org/research-technology-readiness-levels#>
+PREFIX nwo: <https://w3id.org/nwo-research-fields#>
+PREFIX tadirah: <https://vocabs.dariah.eu/tadirah/>
 PREFIX spdx: <http://spdx.org/licences/>
+PREFIX skos: <http://www.w3.org/2004/02/skos/core#>
+PREFIX dct: <http://purl.org/dc/terms/>
 PREFIX orcid: <http://orcid.org/>
 """
 
+NSPREFIXES = ('rdfs:', 'schema:','codemeta:','stype:','iodata:','repostatus:','trl:','nwo:','tadirah:','spdx:','skos:','dct:','orcid:')
     
 
 class CodemetaServer(FastAPI):
@@ -350,7 +357,7 @@ class CodemetaServer(FastAPI):
                     exact = True
                 else:
                     exact = False
-                if not (value.startswith('rdf:') or value.startswith('rdfs:') or value.startswith('schema:') or value.startswith('codemeta:') or value.startswith('stype:') or value.isnumeric()):
+                if not (value.startswith(NSPREFIXES) or value.isnumeric()):
                     value = f"\"{value}\"" #string literal
                 i = len(conditions) + 1
                 if exact:
